@@ -6,21 +6,27 @@
 # Python
 PY_RULE = {
     "block_comment": '""" """',
-    "line_comment": "# "
+    "line_comment": "#"
 }
 
-# C, C++, C#, JAVA, JS
+# C, C++, C#, JAVA, JS, le
 DEFAULT_RULE = {
-    "block_comment": '/* \\*/',
-    "line_comment": "// "
+    "block_comment": '/\* \*/',
+    "line_comment": "\/\/"
 }
 
-# HTML, XML
-ML_RULE = {
+# XML
+XML_RULE = {
     "block_comment": "<!-- -->",
     "line_comment": "<!-- -->"
 }
 
+# HTML
+HTML_RULE = {
+    "block_comment": "<!-- -->",
+    "line_comment": "\/\/"
+}
+
 # JSP
 JSP_RULE = {
     "block_comment": "<%-- --%>",
@@ -34,12 +40,12 @@ FTL_RULE = {
 }
 
 CSS_PHP_RULE = {
-    "block_comment": '/* \\*/',
-    "line_comment": "/* \\*/"
+    "block_comment": '/\* \*/',
+    "line_comment": "/\* \*/"
 }
 
 SQL_RULE = {
-    "block_comment": "/* \\*/",
+    "block_comment": "/\* \*/",
     "line_comment": "-- "
 }
 
